import React from 'react';
import cx from 'clsx';
import Highlight, { defaultProps } from 'prism-react-renderer';
import { useMantineTheme, mergeStyles, Tooltip, ActionIcon, hexToRgba, getThemeColor } from '@mantine/core';
import { useClipboard } from '@mantine/hooks';
import { CopyIcon } from './CopyIcon.js';
import { getPrismTheme } from './prism-theme.js';
import useStyles from './Prism.styles.js';

var __defProp = Object.defineProperty;
var __defProps = Object.defineProperties;
var __getOwnPropDescs = Object.getOwnPropertyDescriptors;
var __getOwnPropSymbols = Object.getOwnPropertySymbols;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __propIsEnum = Object.prototype.propertyIsEnumerable;
var __defNormalProp = (obj, key, value) => key in obj ? __defProp(obj, key, { enumerable: true, configurable: true, writable: true, value }) : obj[key] = value;
var __spreadValues = (a, b) => {
  for (var prop in b || (b = {}))
    if (__hasOwnProp.call(b, prop))
      __defNormalProp(a, prop, b[prop]);
  if (__getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(b)) {
      if (__propIsEnum.call(b, prop))
        __defNormalProp(a, prop, b[prop]);
    }
  return a;
};
var __spreadProps = (a, b) => __defProps(a, __getOwnPropDescs(b));
var __objRest = (source, exclude) => {
  var target = {};
  for (var prop in source)
    if (__hasOwnProp.call(source, prop) && exclude.indexOf(prop) < 0)
      target[prop] = source[prop];
  if (source != null && __getOwnPropSymbols)
    for (var prop of __getOwnPropSymbols(source)) {
      if (exclude.indexOf(prop) < 0 && __propIsEnum.call(source, prop))
        target[prop] = source[prop];
    }
  return target;
};
function Prism(_a) {
  var _b = _a, {
    className,
    style,
    children,
    language,
    noCopy = false,
    themeOverride,
    classNames,
    styles,
    copyLabel = "Copy code",
    copiedLabel = "Copied",
    withLineNumbers = false,
    highlightLines = {}
  } = _b, others = __objRest(_b, [
    "className",
    "style",
    "children",
    "language",
    "noCopy",
    "themeOverride",
    "classNames",
    "styles",
    "copyLabel",
    "copiedLabel",
    "withLineNumbers",
    "highlightLines"
  ]);
  const theme = useMantineTheme(themeOverride);
  const classes = useStyles({ theme }, classNames, "prism");
  const _styles = mergeStyles(classes, styles);
  const clipboard = useClipboard();
  return /* @__PURE__ */ React.createElement("div", __spreadValues({
    className: cx(classes.root, className),
    style: __spreadValues(__spreadValues({}, style), _styles.root)
  }, others), !noCopy && /* @__PURE__ */ React.createElement(Tooltip, {
    "data-mantine-copy": true,
    className: classes.copy,
    style: _styles.copy,
    label: clipboard.copied ? copiedLabel : copyLabel,
    position: "left",
    placement: "center",
    transition: "fade",
    withArrow: true,
    arrowSize: 4,
    gutter: 8,
    color: clipboard.copied ? "teal" : void 0,
    themeOverride
  }, /* @__PURE__ */ React.createElement(ActionIcon, {
    "aria-label": clipboard.copied ? copiedLabel : copyLabel,
    onClick: () => clipboard.copy(children),
    themeOverride
  }, /* @__PURE__ */ React.createElement(CopyIcon, {
    copied: clipboard.copied
  }))), /* @__PURE__ */ React.createElement(Highlight, __spreadProps(__spreadValues({}, defaultProps), {
    theme: getPrismTheme(theme),
    code: children,
    language
  }), ({
    className: inheritedClassName,
    style: inheritedStyle,
    tokens,
    getLineProps,
    getTokenProps
  }) => /* @__PURE__ */ React.createElement("pre", {
    className: cx(classes.code, inheritedClassName, className),
    style: __spreadValues(__spreadValues({}, inheritedStyle), _styles.code)
  }, tokens.map((line, index) => {
    var _a2, _b2, _c, _d;
    if (index === tokens.length - 1 && line.length === 1 && line[0].content === "\n") {
      return null;
    }
    const lineNumber = index + 1;
    const lineProps = getLineProps({ line, key: index });
    const shouldHighlight = lineNumber in highlightLines;
    const lineColor = theme.colorScheme === "dark" ? hexToRgba(getThemeColor({
      theme,
      color: (_a2 = highlightLines[lineNumber]) == null ? void 0 : _a2.color,
      shade: 9
    }), 0.25) : getThemeColor({
      theme,
      color: (_b2 = highlightLines[lineNumber]) == null ? void 0 : _b2.color,
      shade: 0
    });
    return /* @__PURE__ */ React.createElement("div", __spreadProps(__spreadValues({}, lineProps), {
      className: cx(classes.line, lineProps.className),
      style: __spreadValues(__spreadValues({}, _styles.line), shouldHighlight ? { backgroundColor: lineColor } : null)
    }), withLineNumbers && /* @__PURE__ */ React.createElement("div", {
      className: classes.lineNumber,
      "data-mantine-line-number": true,
      style: __spreadProps(__spreadValues({}, _styles.lineNumber), {
        color: shouldHighlight ? getThemeColor({
          theme,
          color: (_c = highlightLines[lineNumber]) == null ? void 0 : _c.color,
          shade: theme.colorScheme === "dark" ? 5 : 8
        }) : void 0
      })
    }, ((_d = highlightLines[lineNumber]) == null ? void 0 : _d.label) || lineNumber), /* @__PURE__ */ React.createElement("div", {
      className: classes.lineContent,
      style: _styles.lineContent
    }, line.map((token, key) => {
      var _a3, _b3;
      const tokenProps = getTokenProps({ token, key });
      return /* @__PURE__ */ React.createElement("span", __spreadProps(__spreadValues({}, tokenProps), {
        style: __spreadProps(__spreadValues({}, tokenProps.style), {
          color: shouldHighlight ? getThemeColor({
            theme,
            color: (_a3 = highlightLines[lineNumber]) == null ? void 0 : _a3.color,
            shade: theme.colorScheme === "dark" ? 5 : 8
          }) : (_b3 = tokenProps == null ? void 0 : tokenProps.style) == null ? void 0 : _b3.color
        })
      }));
    })));
  }).filter(Boolean))));
}
Prism.displayName = "@mantine/prism/Prism";

export { Prism };
//# sourceMappingURL=Prism.js.map
